"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int,
    input_id: str,
    input_processing_configuration: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Adds an InputProcessingConfiguration to an application. An input processor preprocesses records on the input stream before the application's SQL code executes. Currently, the only input processor available is AWS Lambda.

    Args:
        application_name(str): Name of the application to which you want to add the input processing configuration.
        current_application_version_id(int): Version of the application to which you want to add the input processing configuration. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
        input_id(str): The ID of the input configuration to add the input processing configuration to. You can get a list of the input IDs for an application using the DescribeApplication operation.
        input_processing_configuration(Dict): The InputProcessingConfiguration to add to the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.input_.processing_configuration.add(
                ctx,
                application_name=value,
                current_application_version_id=value,
                input_id=value,
                input_processing_configuration=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.input_.processing_configuration.add application_name=value, current_application_version_id=value, input_id=value, input_processing_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="add_application_input_processing_configuration",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "InputId": input_id,
            "InputProcessingConfiguration": input_processing_configuration,
        },
    )


async def delete(
    hub, ctx, application_name: str, current_application_version_id: int, input_id: str
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Deletes an InputProcessingConfiguration from an input.

    Args:
        application_name(str): The Kinesis Analytics application name.
        current_application_version_id(int): The version ID of the Kinesis Analytics application.
        input_id(str): The ID of the input configuration from which to delete the input processing configuration. You can get a list of the input IDs for an application by using the DescribeApplication operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.input_.processing_configuration.delete(
                ctx, application_name=value, current_application_version_id=value, input_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.input_.processing_configuration.delete application_name=value, current_application_version_id=value, input_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="delete_application_input_processing_configuration",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "InputId": input_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, offering_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get details for an offering.

    Args:
        offering_id(str): Unique offering ID, e.g. '87654321'.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.offering.describe(ctx, offering_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.offering.describe offering_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="describe_offering",
        op_kwargs={"OfferingId": offering_id},
    )


async def list_all(
    hub,
    ctx,
    channel_class: str = None,
    channel_configuration: str = None,
    codec: str = None,
    duration: str = None,
    max_results: int = None,
    maximum_bitrate: str = None,
    maximum_framerate: str = None,
    next_token: str = None,
    resolution: str = None,
    resource_type: str = None,
    special_feature: str = None,
    video_quality: str = None,
) -> Dict:
    r"""
        **Autogenerated function**

        List offerings available for purchase.

        Args:
            channel_class(str, optional): Filter by channel class, 'STANDARD' or 'SINGLE_PIPELINE'
    . Defaults to None.
            channel_configuration(str, optional): Filter to offerings that match the configuration of an existing channel, e.g. '2345678' (a channel ID)
    . Defaults to None.
            codec(str, optional): Filter by codec, 'AVC', 'HEVC', 'MPEG2', 'AUDIO', or 'LINK'. Defaults to None.
            duration(str, optional): Filter by offering duration, e.g. '12'. Defaults to None.
            max_results(int, optional): Placeholder documentation for MaxResults. Defaults to None.
            maximum_bitrate(str, optional): Filter by bitrate, 'MAX_10_MBPS', 'MAX_20_MBPS', or 'MAX_50_MBPS'
    . Defaults to None.
            maximum_framerate(str, optional): Filter by framerate, 'MAX_30_FPS' or 'MAX_60_FPS'. Defaults to None.
            next_token(str, optional): Placeholder documentation for __string. Defaults to None.
            resolution(str, optional): Filter by resolution, 'SD', 'HD', 'FHD', or 'UHD'. Defaults to None.
            resource_type(str, optional): Filter by resource type, 'INPUT', 'OUTPUT', 'MULTIPLEX', or 'CHANNEL'. Defaults to None.
            special_feature(str, optional): Filter by special feature, 'ADVANCED_AUDIO' or 'AUDIO_NORMALIZATION'
    . Defaults to None.
            video_quality(str, optional): Filter by video quality, 'STANDARD', 'ENHANCED', or 'PREMIUM'
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.medialive.offering.list_all(ctx)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.medialive.offering.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="list_offerings",
        op_kwargs={
            "ChannelClass": channel_class,
            "ChannelConfiguration": channel_configuration,
            "Codec": codec,
            "Duration": duration,
            "MaxResults": max_results,
            "MaximumBitrate": maximum_bitrate,
            "MaximumFramerate": maximum_framerate,
            "NextToken": next_token,
            "Resolution": resolution,
            "ResourceType": resource_type,
            "SpecialFeature": special_feature,
            "VideoQuality": video_quality,
        },
    )


async def purchase(
    hub,
    ctx,
    count: int,
    offering_id: str,
    name: str = None,
    request_id: str = None,
    start: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Purchase an offering and create a reservation.

    Args:
        count(int): Number of resources.
        name(str, optional): Name for the new reservation. Defaults to None.
        offering_id(str): Offering to purchase, e.g. '87654321'.
        request_id(str, optional): Unique request ID to be specified. This is needed to prevent retries from creating multiple resources. Defaults to None.
        start(str, optional): Requested reservation start time (UTC) in ISO-8601 format. The specified time must be between the first day of the current month and one year from now. If no value is given, the default is now. Defaults to None.
        tags(Dict, optional): A collection of key-value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.offering.purchase(ctx, count=value, offering_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.offering.purchase count=value, offering_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="purchase_offering",
        op_kwargs={
            "Count": count,
            "Name": name,
            "OfferingId": offering_id,
            "RequestId": request_id,
            "Start": start,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the default system parameter information for the DAX caching software.

    Args:
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. The value for MaxResults must be between 20 and 100. Defaults to None.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.default_parameter.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.default_parameter.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="describe_default_parameters",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    license_configuration_arn: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the license configuration operations that failed.

    Args:
        license_configuration_arn(str): Amazon Resource Name of the license configuration.
        max_results(int, optional): Maximum number of results to return in a single call. Defaults to None.
        next_token(str, optional): Token for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.failure_for_license_configuration_operation.list_all(
                ctx, license_configuration_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.failure_for_license_configuration_operation.list_all license_configuration_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="list_failures_for_license_configuration_operations",
        op_kwargs={
            "LicenseConfigurationArn": license_configuration_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    analyzer_name: str,
    type_: str,
    archive_rules: List = None,
    client_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an analyzer for your account.

    Args:
        analyzer_name(str): The name of the analyzer to create.
        archive_rules(List, optional): Specifies the archive rules to add for the analyzer. Archive rules automatically archive findings that meet the criteria you define for the rule. Defaults to None.
        client_token(str, optional): A client token. Defaults to None.
        tags(Dict, optional): The tags to apply to the analyzer. Defaults to None.
        type_(str): The type of analyzer to create. Only ACCOUNT and ORGANIZATION analyzers are supported. You can create only one analyzer per account per Region. You can create up to 5 analyzers per organization per Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.analyzer.create(
                ctx, analyzer_name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.analyzer.create analyzer_name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="create_analyzer",
        op_kwargs={
            "analyzerName": analyzer_name,
            "archiveRules": archive_rules,
            "clientToken": client_token,
            "tags": tags,
            "type": type_,
        },
    )


async def delete(hub, ctx, analyzer_name: str, client_token: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified analyzer. When you delete an analyzer, Access Analyzer is disabled for the account or organization in the current or specific Region. All findings that were generated by the analyzer are deleted. You cannot undo this action.

    Args:
        analyzer_name(str): The name of the analyzer to delete.
        client_token(str, optional): A client token. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.analyzer.delete(ctx, analyzer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.analyzer.delete analyzer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="delete_analyzer",
        op_kwargs={"analyzerName": analyzer_name, "clientToken": client_token},
    )


async def get(hub, ctx, analyzer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified analyzer.

    Args:
        analyzer_name(str): The name of the analyzer retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.analyzer.get(ctx, analyzer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.analyzer.get analyzer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="get_analyzer",
        op_kwargs={"analyzerName": analyzer_name},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, type_: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of analyzers.

    Args:
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token used for pagination of results returned. Defaults to None.
        type_(str, optional): The type of analyzer. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.analyzer.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.analyzer.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="list_analyzers",
        op_kwargs={"maxResults": max_results, "nextToken": next_token, "type": type_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    model_name: str,
    execution_role_arn: str,
    primary_container: Dict = None,
    containers: List = None,
    inference_execution_config: Dict = None,
    tags: List = None,
    vpc_config: Dict = None,
    enable_network_isolation: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a model in Amazon SageMaker. In the request, you name the model and describe a primary container. For the primary container, you specify the Docker image that contains inference code, artifacts (from prior training), and a custom environment map that the inference code uses when you deploy the model for predictions. Use this API to create a model if you want to use Amazon SageMaker hosting services or run a batch transform job. To host your model, you create an endpoint configuration with the CreateEndpointConfig API, and then create an endpoint with the CreateEndpoint API. Amazon SageMaker then deploys all of the containers that you defined for the model in the hosting environment.  For an example that calls this method when deploying a model to Amazon SageMaker hosting services, see Deploy the Model to Amazon SageMaker Hosting Services (Amazon Web Services SDK for Python (Boto 3)).  To run a batch transform using your model, you start a job with the CreateTransformJob API. Amazon SageMaker uses your model and your dataset to get inferences which are then saved to a specified S3 location. In the CreateModel request, you must define a container with the PrimaryContainer parameter. In the request, you also provide an IAM role that Amazon SageMaker can assume to access model artifacts and docker image for deployment on ML compute hosting instances or for batch transform jobs. In addition, you also use the IAM role to manage permissions the inference code needs. For example, if the inference code access any other Amazon Web Services resources, you grant necessary permissions via this role.

    Args:
        model_name(str): The name of the new model.
        primary_container(Dict, optional): The location of the primary docker image containing inference code, associated artifacts, and custom environment map that the inference code uses when the model is deployed for predictions. . Defaults to None.
        containers(List, optional): Specifies the containers in the inference pipeline. Defaults to None.
        inference_execution_config(Dict, optional): Specifies details of how containers in a multi-container endpoint are called. Defaults to None.
        execution_role_arn(str): The Amazon Resource Name (ARN) of the IAM role that Amazon SageMaker can assume to access model artifacts and docker image for deployment on ML compute instances or for batch transform jobs. Deploying on ML compute instances is part of model hosting. For more information, see Amazon SageMaker Roles.   To be able to pass this role to Amazon SageMaker, the caller of this API must have the iam:PassRole permission. .
        tags(List, optional): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources. Defaults to None.
        vpc_config(Dict, optional): A VpcConfig object that specifies the VPC that you want your model to connect to. Control access to and from your model container by configuring the VPC. VpcConfig is used in hosting services and in batch transform. For more information, see Protect Endpoints by Using an Amazon Virtual Private Cloud and Protect Data in Batch Transform Jobs by Using an Amazon Virtual Private Cloud. Defaults to None.
        enable_network_isolation(bool, optional): Isolates the model container. No inbound or outbound network calls can be made to or from the model container. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.init.create(
                ctx, model_name=value, execution_role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.init.create model_name=value, execution_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_model",
        op_kwargs={
            "ModelName": model_name,
            "PrimaryContainer": primary_container,
            "Containers": containers,
            "InferenceExecutionConfig": inference_execution_config,
            "ExecutionRoleArn": execution_role_arn,
            "Tags": tags,
            "VpcConfig": vpc_config,
            "EnableNetworkIsolation": enable_network_isolation,
        },
    )


async def delete(hub, ctx, model_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a model. The DeleteModel API deletes only the model entry that was created in Amazon SageMaker when you called the CreateModel API. It does not delete model artifacts, inference code, or the IAM role that you specified when creating the model.

    Args:
        model_name(str): The name of the model to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.init.delete(ctx, model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.init.delete model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_model",
        op_kwargs={"ModelName": model_name},
    )


async def describe(hub, ctx, model_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a model that you created using the CreateModel API.

    Args:
        model_name(str): The name of the model.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.init.describe(ctx, model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.init.describe model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_model",
        op_kwargs={"ModelName": model_name},
    )


async def list_all(
    hub,
    ctx,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
    name_contains: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists models created with the CreateModel API.

    Args:
        sort_by(str, optional): Sorts the list of results. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Descending. Defaults to None.
        next_token(str, optional): If the response to a previous ListModels request was truncated, the response includes a NextToken. To retrieve the next set of models, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of models to return in the response. Defaults to None.
        name_contains(str, optional): A string in the training job name. This filter returns only models in the training job whose name contains the specified string. Defaults to None.
        creation_time_before(str, optional): A filter that returns only models created before the specified time (timestamp). Defaults to None.
        creation_time_after(str, optional): A filter that returns only models with a creation time greater than or equal to the specified time (timestamp). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_models",
        op_kwargs={
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an outcome. You cannot delete an outcome that is used in a rule version. When you delete an outcome, Amazon Fraud Detector permanently deletes that outcome and the data is no longer stored in Amazon Fraud Detector.

    Args:
        name(str): The name of the outcome to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.outcome.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.outcome.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_outcome",
        op_kwargs={"name": name},
    )


async def get_all(
    hub, ctx, name: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets one or more outcomes. This is a paginated API. If you provide a null maxResults, this actions retrieves a maximum of 100 records per page. If you provide a maxResults, the value must be between 50 and 100. To get the next page results, provide the pagination token from the GetOutcomesResult as part of your request. A null pagination token fetches the records from the beginning.

    Args:
        name(str, optional): The name of the outcome or outcomes to get. Defaults to None.
        next_token(str, optional): The next page token for the request. . Defaults to None.
        max_results(int, optional): The maximum number of objects to return for the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.outcome.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.outcome.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_outcomes",
        op_kwargs={"name": name, "nextToken": next_token, "maxResults": max_results},
    )


async def put(hub, ctx, name: str, description: str = None, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates an outcome.

    Args:
        name(str): The name of the outcome.
        description(str, optional): The outcome description. Defaults to None.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.outcome.put(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.outcome.put name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="put_outcome",
        op_kwargs={"name": name, "description": description, "tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, phone_config: Dict, user_id: str, instance_id: str) -> None:
    r"""
    **Autogenerated function**

    Updates the phone configuration settings for the specified user.

    Args:
        phone_config(Dict): Information about phone configuration settings for the user.
        user_id(str): The identifier of the user account.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.phone_config.update(
                ctx, phone_config=value, user_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.phone_config.update phone_config=value, user_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_user_phone_config",
        op_kwargs={
            "PhoneConfig": phone_config,
            "UserId": user_id,
            "InstanceId": instance_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, name: str, document_reviews: Dict, document_version: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates information related to approval reviews for a specific version of a document.

    Args:
        name(str): The name of the document for which a version is to be updated.
        document_version(str, optional): The version of a document to update. Defaults to None.
        document_reviews(Dict): The document review details to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.metadata.init.update(
                ctx, name=value, document_reviews=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.metadata.init.update name=value, document_reviews=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_document_metadata",
        op_kwargs={
            "Name": name,
            "DocumentVersion": document_version,
            "DocumentReviews": document_reviews,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, instance_ids: List = None, max_records: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the Auto Scaling instances in the account and Region.

    Args:
        instance_ids(List, optional): The IDs of the instances. If you omit this parameter, all Auto Scaling instances are described. If you specify an ID that does not exist, it is ignored with no error. Array Members: Maximum number of 50 items. Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 50 and the maximum value is 50. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.auto_scaling.instance.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.auto_scaling.instance.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_auto_scaling_instances",
        op_kwargs={
            "InstanceIds": instance_ids,
            "MaxRecords": max_records,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, firewall_rule_group_association_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group. A VPC can have more than one firewall rule group association, and a rule group can be associated with more than one VPC.

    Args:
        firewall_rule_group_association_id(str): The identifier of the FirewallRuleGroupAssociation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.association.get(
                ctx, firewall_rule_group_association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.association.get firewall_rule_group_association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_firewall_rule_group_association",
        op_kwargs={
            "FirewallRuleGroupAssociationId": firewall_rule_group_association_id
        },
    )


async def list_all(
    hub,
    ctx,
    firewall_rule_group_id: str = None,
    vpc_id: str = None,
    priority: int = None,
    status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the firewall rule group associations that you have defined. Each association enables DNS filtering for a VPC with one rule group.  A single call might return only a partial list of the associations. For information, see MaxResults.

    Args:
        firewall_rule_group_id(str, optional): The unique identifier of the firewall rule group that you want to retrieve the associations for. Leave this blank to retrieve associations for any rule group. . Defaults to None.
        vpc_id(str, optional): The unique identifier of the VPC that you want to retrieve the associations for. Leave this blank to retrieve associations for any VPC. . Defaults to None.
        priority(int, optional): The setting that determines the processing order of the rule group among the rule groups that are associated with a single VPC. DNS Firewall filters VPC traffic starting from the rule group with the lowest numeric priority setting. . Defaults to None.
        status(str, optional): The association Status setting that you want DNS Firewall to filter on for the list. If you don't specify this, then DNS Firewall returns all associations, regardless of status. Defaults to None.
        max_results(int, optional): The maximum number of objects that you want Resolver to return for this request. If more objects are available, in the response, Resolver provides a NextToken value that you can use in a subsequent call to get the next batch of objects. If you don't specify a value for MaxResults, Resolver returns up to 100 objects. . Defaults to None.
        next_token(str, optional): For the first call to this list request, omit this value. When you request a list of objects, Resolver returns at most the number of objects specified in MaxResults. If more objects are available for retrieval, Resolver returns a NextToken value in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.association.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.association.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_firewall_rule_group_associations",
        op_kwargs={
            "FirewallRuleGroupId": firewall_rule_group_id,
            "VpcId": vpc_id,
            "Priority": priority,
            "Status": status,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    firewall_rule_group_association_id: str,
    priority: int = None,
    mutation_protection: str = None,
    name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the association of a FirewallRuleGroup with a VPC. The association enables DNS filtering for the VPC.

    Args:
        firewall_rule_group_association_id(str): The identifier of the FirewallRuleGroupAssociation. .
        priority(int, optional): The setting that determines the processing order of the rule group among the rule groups that you associate with the specified VPC. DNS Firewall filters VPC traffic starting from the rule group with the lowest numeric priority setting.  You must specify a unique priority for each rule group that you associate with a single VPC. To make it easier to insert rule groups later, leave space between the numbers, for example, use 100, 200, and so on. You can change the priority setting for a rule group association after you create it. Defaults to None.
        mutation_protection(str, optional): If enabled, this setting disallows modification or removal of the association, to help prevent against accidentally altering DNS firewall protections. . Defaults to None.
        name(str, optional): The name of the rule group association. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.association.update(
                ctx, firewall_rule_group_association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.association.update firewall_rule_group_association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="update_firewall_rule_group_association",
        op_kwargs={
            "FirewallRuleGroupAssociationId": firewall_rule_group_association_id,
            "Priority": priority,
            "MutationProtection": mutation_protection,
            "Name": name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def accept(hub, ctx, input_device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Accept an incoming input device transfer. The ownership of the device will transfer to your AWS account.

    Args:
        input_device_id(str): The unique ID of the input device to accept. For example, hd-123456789abcdef.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.device.transfer.accept(
                ctx, input_device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.device.transfer.accept input_device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="accept_input_device_transfer",
        op_kwargs={"InputDeviceId": input_device_id},
    )


async def cancel(hub, ctx, input_device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancel an input device transfer that you have requested.

    Args:
        input_device_id(str): The unique ID of the input device to cancel. For example, hd-123456789abcdef.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.device.transfer.cancel(
                ctx, input_device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.device.transfer.cancel input_device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="cancel_input_device_transfer",
        op_kwargs={"InputDeviceId": input_device_id},
    )


async def list_all(
    hub, ctx, transfer_type: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List input devices that are currently being transferred. List input devices that you are transferring from your AWS account or input devices that another AWS account is transferring to you.

    Args:
        max_results(int, optional): Placeholder documentation for MaxResults. Defaults to None.
        next_token(str, optional): Placeholder documentation for __string. Defaults to None.
        transfer_type(str): Placeholder documentation for __string.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.device.transfer.list_all(
                ctx, transfer_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.device.transfer.list_all transfer_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="list_input_device_transfers",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "TransferType": transfer_type,
        },
    )


async def reject(hub, ctx, input_device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Reject the transfer of the specified input device to your AWS account.

    Args:
        input_device_id(str): The unique ID of the input device to reject. For example, hd-123456789abcdef.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.device.transfer.reject(
                ctx, input_device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.device.transfer.reject input_device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="reject_input_device_transfer",
        op_kwargs={"InputDeviceId": input_device_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "match_set"


async def create(hub, ctx, name: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates a RegexMatchSet. You then use UpdateRegexMatchSet to identify the part of a web request that you want AWS WAF to inspect, such as the values of the User-Agent header or the query string. For example, you can create a RegexMatchSet that contains a RegexMatchTuple that looks for any requests with User-Agent headers that match a RegexPatternSet with pattern B[a@]dB[o0]t. You can then configure AWS WAF to reject those requests. To create and configure a RegexMatchSet, perform the following steps:   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateRegexMatchSet request.   Submit a CreateRegexMatchSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateRegexMatchSet request.   Submit an UpdateRegexMatchSet request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the value, using a RegexPatternSet, that you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the RegexMatchSet. You can't change Name after you create a RegexMatchSet.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.match_set_.create(
                ctx, name=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.match_set.create name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_regex_match_set",
        op_kwargs={"Name": name, "ChangeToken": change_token},
    )


async def delete(hub, ctx, regex_match_set_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a RegexMatchSet. You can't delete a RegexMatchSet if it's still used in any Rules or if it still includes any RegexMatchTuples objects (any filters). If you just want to remove a RegexMatchSet from a Rule, use UpdateRule. To permanently delete a RegexMatchSet, perform the following steps:   Update the RegexMatchSet to remove filters, if any. For more information, see UpdateRegexMatchSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteRegexMatchSet request.   Submit a DeleteRegexMatchSet request.

    Args:
        regex_match_set_id(str): The RegexMatchSetId of the RegexMatchSet that you want to delete. RegexMatchSetId is returned by CreateRegexMatchSet and by ListRegexMatchSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.match_set_.delete(
                ctx, regex_match_set_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.match_set.delete regex_match_set_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_regex_match_set",
        op_kwargs={"RegexMatchSetId": regex_match_set_id, "ChangeToken": change_token},
    )


async def get(hub, ctx, regex_match_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the RegexMatchSet specified by RegexMatchSetId.

    Args:
        regex_match_set_id(str): The RegexMatchSetId of the RegexMatchSet that you want to get. RegexMatchSetId is returned by CreateRegexMatchSet and by ListRegexMatchSets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.match_set_.get(ctx, regex_match_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.match_set.get regex_match_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_regex_match_set",
        op_kwargs={"RegexMatchSetId": regex_match_set_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of RegexMatchSetSummary objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more RegexMatchSet objects than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of ByteMatchSets. For the second and subsequent ListRegexMatchSets requests, specify the value of NextMarker from the previous response to get information about another batch of RegexMatchSet objects. Defaults to None.
        limit(int, optional): Specifies the number of RegexMatchSet objects that you want AWS WAF to return for this request. If you have more RegexMatchSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of RegexMatchSet objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.match_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.match_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_regex_match_sets",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub, ctx, regex_match_set_id: str, updates: List, change_token: str
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes RegexMatchTuple objects (filters) in a RegexMatchSet. For each RegexMatchSetUpdate object, you specify the following values:    Whether to insert or delete the object from the array. If you want to change a RegexMatchSetUpdate object, you delete the existing object and add a new one.   The part of a web request that you want AWS WAF to inspectupdate, such as a query string or the value of the User-Agent header.    The identifier of the pattern (a regular expression) that you want AWS WAF to look for. For more information, see RegexPatternSet.    Whether to perform any conversions on the request, such as converting it to lowercase, before inspecting it for the specified string.    For example, you can create a RegexPatternSet that matches any requests with User-Agent headers that contain the string B[a@]dB[o0]t. You can then configure AWS WAF to reject those requests. To create and configure a RegexMatchSet, perform the following steps:   Create a RegexMatchSet. For more information, see CreateRegexMatchSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateRegexMatchSet request.   Submit an UpdateRegexMatchSet request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the identifier of the RegexPatternSet that contain the regular expression patters you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        regex_match_set_id(str): The RegexMatchSetId of the RegexMatchSet that you want to update. RegexMatchSetId is returned by CreateRegexMatchSet and by ListRegexMatchSets.
        updates(List): An array of RegexMatchSetUpdate objects that you want to insert into or delete from a RegexMatchSet. For more information, see RegexMatchTuple.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.match_set_.update(
                ctx, regex_match_set_id=value, updates=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.match_set.update regex_match_set_id=value, updates=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_regex_match_set",
        op_kwargs={
            "RegexMatchSetId": regex_match_set_id,
            "Updates": updates,
            "ChangeToken": change_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    settings: Dict,
    acceleration_settings: Dict = None,
    category: str = None,
    description: str = None,
    hop_destinations: List = None,
    priority: int = None,
    queue: str = None,
    status_update_interval: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new job template. For information about job templates see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html

    Args:
        acceleration_settings(Dict, optional): Accelerated transcoding can significantly speed up jobs with long, visually complex content. Outputs that use this feature incur pro-tier pricing. For information about feature limitations, see the AWS Elemental MediaConvert User Guide. Defaults to None.
        category(str, optional): Optional. A category for the job template you are creating. Defaults to None.
        description(str, optional): Optional. A description of the job template you are creating. Defaults to None.
        hop_destinations(List, optional): Optional. Use queue hopping to avoid overly long waits in the backlog of the queue that you submit your job to. Specify an alternate queue and the maximum time that your job will wait in the initial queue before hopping. For more information about this feature, see the AWS Elemental MediaConvert User Guide. Defaults to None.
        name(str): The name of the job template you are creating.
        priority(int, optional): Specify the relative priority for this job. In any given queue, the service begins processing the job with the highest value first. When more than one job has the same priority, the service begins processing the job that you submitted first. If you don't specify a priority, the service uses the default value 0. Defaults to None.
        queue(str, optional): Optional. The queue that jobs created from this template are assigned to. If you don't specify this, jobs will go to the default queue. Defaults to None.
        settings(Dict): JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it.
        status_update_interval(str, optional): Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error. Defaults to None.
        tags(Dict, optional): The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.job.template.create(
                ctx, name=value, settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.job.template.create name=value, settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="create_job_template",
        op_kwargs={
            "AccelerationSettings": acceleration_settings,
            "Category": category,
            "Description": description,
            "HopDestinations": hop_destinations,
            "Name": name,
            "Priority": priority,
            "Queue": queue,
            "Settings": settings,
            "StatusUpdateInterval": status_update_interval,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently delete a job template you have created.

    Args:
        name(str): The name of the job template to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.job.template.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.job.template.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="delete_job_template",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve the JSON for a specific job template.

    Args:
        name(str): The name of the job template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.job.template.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.job.template.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="get_job_template",
        op_kwargs={"Name": name},
    )


async def list_all(
    hub,
    ctx,
    category: str = None,
    list_by: str = None,
    max_results: int = None,
    next_token: str = None,
    order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a JSON array of up to twenty of your job templates. This will return the templates themselves, not just a list of them. To retrieve the next twenty templates, use the nextToken string returned with the array

    Args:
        category(str, optional): Optionally, specify a job template category to limit responses to only job templates from that category. Defaults to None.
        list_by(str, optional): Optional. When you request a list of job templates, you can choose to list them alphabetically by NAME or chronologically by CREATION_DATE. If you don't specify, the service will list them by name. Defaults to None.
        max_results(int, optional): Optional. Number of job templates, up to twenty, that will be returned at one time. Defaults to None.
        next_token(str, optional): Use this string, provided with the response to a previous request, to request the next batch of job templates. Defaults to None.
        order(str, optional): Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.job.template.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.job.template.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="list_job_templates",
        op_kwargs={
            "Category": category,
            "ListBy": list_by,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Order": order,
        },
    )


async def update(
    hub,
    ctx,
    name: str,
    acceleration_settings: Dict = None,
    category: str = None,
    description: str = None,
    hop_destinations: List = None,
    priority: int = None,
    queue: str = None,
    settings: Dict = None,
    status_update_interval: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modify one of your existing job templates.

    Args:
        acceleration_settings(Dict, optional): Accelerated transcoding can significantly speed up jobs with long, visually complex content. Outputs that use this feature incur pro-tier pricing. For information about feature limitations, see the AWS Elemental MediaConvert User Guide. Defaults to None.
        category(str, optional): The new category for the job template, if you are changing it. Defaults to None.
        description(str, optional): The new description for the job template, if you are changing it. Defaults to None.
        hop_destinations(List, optional): Optional list of hop destinations. Defaults to None.
        name(str): The name of the job template you are modifying.
        priority(int, optional): Specify the relative priority for this job. In any given queue, the service begins processing the job with the highest value first. When more than one job has the same priority, the service begins processing the job that you submitted first. If you don't specify a priority, the service uses the default value 0. Defaults to None.
        queue(str, optional): The new queue for the job template, if you are changing it. Defaults to None.
        settings(Dict, optional): JobTemplateSettings contains all the transcode settings saved in the template that will be applied to jobs created from it. Defaults to None.
        status_update_interval(str, optional): Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.job.template.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.job.template.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="update_job_template",
        op_kwargs={
            "AccelerationSettings": acceleration_settings,
            "Category": category,
            "Description": description,
            "HopDestinations": hop_destinations,
            "Name": name,
            "Priority": priority,
            "Queue": queue,
            "Settings": settings,
            "StatusUpdateInterval": status_update_interval,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    engine: str = None,
    engine_version: str = None,
    cache_parameter_group_family: str = None,
    max_records: int = None,
    marker: str = None,
    default_only: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the available cache engines and their versions.

    Args:
        engine(str, optional): The cache engine to return. Valid values: memcached | redis . Defaults to None.
        engine_version(str, optional): The cache engine version to return. Example: 1.4.14 . Defaults to None.
        cache_parameter_group_family(str, optional): The name of a specific cache parameter group family to return details for. Valid values are: memcached1.4 | memcached1.5 | memcached1.6 | redis2.6 | redis2.8 | redis3.2 | redis4.0 | redis5.0 | redis6.x |  Constraints:   Must be 1 to 255 alphanumeric characters   First character must be a letter   Cannot end with a hyphen or contain two consecutive hyphens  . Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: minimum 20; maximum 100. Defaults to None.
        marker(str, optional): An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.
        default_only(bool, optional): If true, specifies that only the default version of the specified engine or engine and major version combination is to be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.cache.engine_version.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.cache.engine_version.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="describe_cache_engine_versions",
        op_kwargs={
            "Engine": engine,
            "EngineVersion": engine_version,
            "CacheParameterGroupFamily": cache_parameter_group_family,
            "MaxRecords": max_records,
            "Marker": marker,
            "DefaultOnly": default_only,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(hub, ctx, directory_id: str, certificate_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes from the system the certificate that was registered for secure LDAP or client certificate authentication.

    Args:
        directory_id(str): The identifier of the directory.
        certificate_id(str): The identifier of the certificate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.certificate.deregister(
                ctx, directory_id=value, certificate_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.certificate.deregister directory_id=value, certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="deregister_certificate",
        op_kwargs={"DirectoryId": directory_id, "CertificateId": certificate_id},
    )


async def describe(hub, ctx, directory_id: str, certificate_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays information about the certificate registered for secure LDAP or client certificate authentication.

    Args:
        directory_id(str): The identifier of the directory.
        certificate_id(str): The identifier of the certificate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.certificate.describe(
                ctx, directory_id=value, certificate_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.certificate.describe directory_id=value, certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="describe_certificate",
        op_kwargs={"DirectoryId": directory_id, "CertificateId": certificate_id},
    )


async def list_all(
    hub, ctx, directory_id: str, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    For the specified directory, lists all the certificates registered for a secure LDAP or client certificate authentication.

    Args:
        directory_id(str): The identifier of the directory.
        next_token(str, optional): A token for requesting another page of certificates if the NextToken response element indicates that more certificates are available. Use the value of the returned NextToken element in your request until the token comes back as null. Pass null if this is the first call. Defaults to None.
        limit(int, optional): The number of items that should show up on one page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.certificate.list_all(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.certificate.list_all directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="list_certificates",
        op_kwargs={
            "DirectoryId": directory_id,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def register(
    hub,
    ctx,
    directory_id: str,
    certificate_data: str,
    type_: str = None,
    client_cert_auth_settings: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a certificate for a secure LDAP or client certificate authentication.

    Args:
        directory_id(str): The identifier of the directory.
        certificate_data(str): The certificate PEM string that needs to be registered.
        type_(str, optional): The function that the registered certificate performs. Valid values include ClientLDAPS or ClientCertAuth. The default value is ClientLDAPS. Defaults to None.
        client_cert_auth_settings(Dict, optional): A ClientCertAuthSettings object that contains client certificate authentication settings. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.certificate.register(
                ctx, directory_id=value, certificate_data=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.certificate.register directory_id=value, certificate_data=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="register_certificate",
        op_kwargs={
            "DirectoryId": directory_id,
            "CertificateData": certificate_data,
            "Type": type_,
            "ClientCertAuthSettings": client_cert_auth_settings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    query_string: str,
    index_name: str = None,
    aggregation_field: str = None,
    query_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the approximate count of unique values that match the query.

    Args:
        index_name(str, optional): The name of the index to search. Defaults to None.
        query_string(str): The search query.
        aggregation_field(str, optional): The field to aggregate. Defaults to None.
        query_version(str, optional): The query version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.cardinality.get(ctx, query_string=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.cardinality.get query_string=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="get_cardinality",
        op_kwargs={
            "indexName": index_name,
            "queryString": query_string,
            "aggregationField": aggregation_field,
            "queryVersion": query_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def restore(
    hub,
    ctx,
    db_cluster_identifier: str,
    snapshot_identifier: str,
    engine: str,
    availability_zones: List = None,
    engine_version: str = None,
    port: int = None,
    db_subnet_group_name: str = None,
    database_name: str = None,
    option_group_name: str = None,
    vpc_security_group_ids: List = None,
    tags: List = None,
    kms_key_id: str = None,
    enable_iam_database_authentication: bool = None,
    backtrack_window: int = None,
    enable_cloudwatch_logs_exports: List = None,
    engine_mode: str = None,
    scaling_configuration: Dict = None,
    db_cluster_parameter_group_name: str = None,
    deletion_protection: bool = None,
    copy_tags_to_snapshot: bool = None,
    domain: str = None,
    domain_iam_role_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DB cluster from a DB snapshot or DB cluster snapshot. This action only applies to Aurora DB clusters. The target DB cluster is created from the source snapshot with a default configuration. If you don't specify a security group, the new DB cluster is associated with the default security group.  This action only restores the DB cluster, not the DB instances for that DB cluster. You must invoke the CreateDBInstance action to create DB instances for the restored DB cluster, specifying the identifier of the restored DB cluster in DBClusterIdentifier. You can create DB instances only after the RestoreDBClusterFromSnapshot action has completed and the DB cluster is available.  For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters.

    Args:
        availability_zones(List, optional): Provides the list of Availability Zones (AZs) where instances in the restored DB cluster can be created. Defaults to None.
        db_cluster_identifier(str): The name of the DB cluster to create from the DB snapshot or DB cluster snapshot. This parameter isn't case-sensitive. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens   Example: my-snapshot-id .
        snapshot_identifier(str): The identifier for the DB snapshot or DB cluster snapshot to restore from. You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot. Constraints:   Must match the identifier of an existing Snapshot.  .
        engine(str): The database engine to use for the new DB cluster. Default: The same as source Constraint: Must be compatible with the engine of the source.
        engine_version(str, optional): The version of the database engine to use for the new DB cluster. To list all of the available engine versions for aurora (for MySQL 5.6-compatible Aurora), use the following command:  aws rds describe-db-engine-versions --engine aurora --query "DBEngineVersions[].EngineVersion"  To list all of the available engine versions for aurora-mysql (for MySQL 5.7-compatible Aurora), use the following command:  aws rds describe-db-engine-versions --engine aurora-mysql --query "DBEngineVersions[].EngineVersion"  To list all of the available engine versions for aurora-postgresql, use the following command:  aws rds describe-db-engine-versions --engine aurora-postgresql --query "DBEngineVersions[].EngineVersion"   If you aren't using the default engine version, then you must specify the engine version.   Aurora MySQL  Example: 5.6.10a, 5.6.mysql_aurora.1.19.2, 5.7.12, 5.7.mysql_aurora.2.04.5   Aurora PostgreSQL  Example: 9.6.3, 10.7 . Defaults to None.
        port(int, optional): The port number on which the new DB cluster accepts connections. Constraints: This value must be 1150-65535  Default: The same port as the original DB cluster. Defaults to None.
        db_subnet_group_name(str, optional): The name of the DB subnet group to use for the new DB cluster. Constraints: If supplied, must match the name of an existing DB subnet group. Example: mySubnetgroup . Defaults to None.
        database_name(str, optional): The database name for the restored DB cluster. Defaults to None.
        option_group_name(str, optional): The name of the option group to use for the restored DB cluster. Defaults to None.
        vpc_security_group_ids(List, optional): A list of VPC security groups that the new DB cluster will belong to. Defaults to None.
        tags(List, optional): The tags to be assigned to the restored DB cluster. Defaults to None.
        kms_key_id(str, optional): The Amazon Web Services KMS key identifier to use when restoring an encrypted DB cluster from a DB snapshot or DB cluster snapshot. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the Amazon Web Services KMS customer master key (CMK). To use a CMK in a different Amazon Web Services account, specify the key ARN or alias ARN. When you don't specify a value for the KmsKeyId parameter, then the following occurs:   If the DB snapshot or DB cluster snapshot in SnapshotIdentifier is encrypted, then the restored DB cluster is encrypted using the Amazon Web Services KMS CMK that was used to encrypt the DB snapshot or DB cluster snapshot.   If the DB snapshot or DB cluster snapshot in SnapshotIdentifier isn't encrypted, then the restored DB cluster isn't encrypted.  . Defaults to None.
        enable_iam_database_authentication(bool, optional): A value that indicates whether to enable mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts. By default, mapping is disabled. For more information, see  IAM Database Authentication in the Amazon Aurora User Guide. . Defaults to None.
        backtrack_window(int, optional): The target backtrack window, in seconds. To disable backtracking, set this value to 0.  Currently, Backtrack is only supported for Aurora MySQL DB clusters.  Default: 0 Constraints:   If specified, this value must be set to a number from 0 to 259,200 (72 hours).  . Defaults to None.
        enable_cloudwatch_logs_exports(List, optional): The list of logs that the restored DB cluster is to export to Amazon CloudWatch Logs. The values in the list depend on the DB engine being used. For more information, see Publishing Database Logs to Amazon CloudWatch Logs  in the Amazon Aurora User Guide. Defaults to None.
        engine_mode(str, optional): The DB engine mode of the DB cluster, either provisioned, serverless, parallelquery, global, or multimaster. For more information, see  CreateDBCluster. Defaults to None.
        scaling_configuration(Dict, optional): For DB clusters in serverless DB engine mode, the scaling properties of the DB cluster. Defaults to None.
        db_cluster_parameter_group_name(str, optional): The name of the DB cluster parameter group to associate with this DB cluster. If this argument is omitted, the default DB cluster parameter group for the specified engine is used. Constraints:   If supplied, must match the name of an existing default DB cluster parameter group.   Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter.   Can't end with a hyphen or contain two consecutive hyphens.  . Defaults to None.
        deletion_protection(bool, optional): A value that indicates whether the DB cluster has deletion protection enabled. The database can't be deleted when deletion protection is enabled. By default, deletion protection is disabled. . Defaults to None.
        copy_tags_to_snapshot(bool, optional): A value that indicates whether to copy all tags from the restored DB cluster to snapshots of the restored DB cluster. The default is not to copy them. Defaults to None.
        domain(str, optional): Specify the Active Directory directory ID to restore the DB cluster in. The domain must be created prior to this operation. Currently, only MySQL, Microsoft SQL Server, Oracle, and PostgreSQL DB instances can be created in an Active Directory Domain. For more information, see  Kerberos Authentication in the Amazon RDS User Guide. . Defaults to None.
        domain_iam_role_name(str, optional): Specify the name of the IAM role to be used when making API calls to the Directory Service. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.cluster.from_.snapshot.restore(
                ctx, db_cluster_identifier=value, snapshot_identifier=value, engine=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.cluster.from_.snapshot.restore db_cluster_identifier=value, snapshot_identifier=value, engine=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="restore_db_cluster_from_snapshot",
        op_kwargs={
            "AvailabilityZones": availability_zones,
            "DBClusterIdentifier": db_cluster_identifier,
            "SnapshotIdentifier": snapshot_identifier,
            "Engine": engine,
            "EngineVersion": engine_version,
            "Port": port,
            "DBSubnetGroupName": db_subnet_group_name,
            "DatabaseName": database_name,
            "OptionGroupName": option_group_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "Tags": tags,
            "KmsKeyId": kms_key_id,
            "EnableIAMDatabaseAuthentication": enable_iam_database_authentication,
            "BacktrackWindow": backtrack_window,
            "EnableCloudwatchLogsExports": enable_cloudwatch_logs_exports,
            "EngineMode": engine_mode,
            "ScalingConfiguration": scaling_configuration,
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "DeletionProtection": deletion_protection,
            "CopyTagsToSnapshot": copy_tags_to_snapshot,
            "Domain": domain,
            "DomainIAMRoleName": domain_iam_role_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Assigns one or more tags (key-value pairs) to the specified QuickSight resource.  Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only resources with certain tag values. You can use the TagResource operation with a resource that already has tags. If you specify a new tag key for the resource, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag. You can associate as many as 50 tags with a resource. QuickSight supports tagging on data set, data source, dashboard, and template.  Tagging for QuickSight works in a similar way to tagging for other AWS services, except for the following:   You can't use tags to track AWS costs for QuickSight. This restriction is because QuickSight costs are based on users and SPICE capacity, which aren't taggable resources.   QuickSight doesn't currently support the Tag Editor for Resource Groups.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that you want to tag.
        tags(List): Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes a tag or tags from a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that you want to untag.
        tag_keys(List): The keys of the key-value pairs for the resource tag or tags assigned to the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, cluster_arn: str, secret_arn_list: List) -> Dict:
    r"""
        **Autogenerated function**


        Associates one or more Scram Secrets with an Amazon MSK cluster.


        Args:
            cluster_arn(str):
    The Amazon Resource Name (ARN) of the cluster to be updated.
    .
            secret_arn_list(List):
    List of AWS Secrets Manager secret ARNs.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.associate_scram_secret.batch(
                    ctx, cluster_arn=value, secret_arn_list=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.associate_scram_secret.batch cluster_arn=value, secret_arn_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="batch_associate_scram_secret",
        op_kwargs={"ClusterArn": cluster_arn, "SecretArnList": secret_arn_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    filters: List = None,
    instance_ids: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the credit option for CPU usage of the specified burstable performance instances. The credit options are standard and unlimited. If you do not specify an instance ID, Amazon EC2 returns burstable performance instances with the unlimited credit option, as well as instances that were previously configured as T2, T3, and T3a with the unlimited credit option. For example, if you resize a T2 instance, while it is configured as unlimited, to an M4 instance, Amazon EC2 returns the M4 instance. If you specify one or more instance IDs, Amazon EC2 returns the credit option (standard or unlimited) of those instances. If you specify an instance ID that is not valid, such as an instance that is not a burstable performance instance, an error is returned. Recently terminated instances might appear in the returned results. This interval is usually less than one hour. If an Availability Zone is experiencing a service disruption and you specify instance IDs in the affected zone, or do not specify any instance IDs at all, the call fails. If you specify only instance IDs in an unaffected zone, the call works normally. For more information, see Burstable performance instances in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): The filters.    instance-id - The ID of the instance.  . Defaults to None.
        instance_ids(List, optional): The instance IDs. Default: Describes all your instances. Constraints: Maximum 1000 explicitly specified instance IDs. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 5 and 1000. You cannot specify this parameter and the instance IDs parameter in the same call. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.credit_specification.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.credit_specification.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_instance_credit_specifications",
        op_kwargs={
            "DryRun": dry_run,
            "Filters": filters,
            "InstanceIds": instance_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def modify(
    hub,
    ctx,
    instance_credit_specifications: List,
    dry_run: bool = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the credit option for CPU usage on a running or stopped burstable performance instance. The credit options are standard and unlimited. For more information, see Burstable performance instances in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency. Defaults to None.
        instance_credit_specifications(List): Information about the credit option for CPU usage.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.credit_specification.modify(
                ctx, instance_credit_specifications=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.credit_specification.modify instance_credit_specifications=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_instance_credit_specification",
        op_kwargs={
            "DryRun": dry_run,
            "ClientToken": client_token,
            "InstanceCreditSpecifications": instance_credit_specifications,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    account_id: str,
    next_token: str = None,
    max_results: int = None,
    outpost_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all Outposts buckets in an Outpost that are owned by the authenticated sender of the request. For more information, see Using Amazon S3 on Outposts in the Amazon S3 User Guide. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and x-amz-outpost-id in your request, see the Examples section.

    Args:
        account_id(str): The account ID of the Outposts bucket.
        next_token(str, optional): . Defaults to None.
        max_results(int, optional): . Defaults to None.
        outpost_id(str, optional): The ID of the Outposts.  This is required by Amazon S3 on Outposts buckets. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.regional_bucket.list_all(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.regional_bucket.list_all account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="list_regional_buckets",
        op_kwargs={
            "AccountId": account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "OutpostId": outpost_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags_model: Dict) -> None:
    r"""
    **Autogenerated function**

    Adds one or more tags (keys and values) to an application, campaign, message template, or segment.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tags_model(Dict): Specifies the tags (keys and values) for an application, campaign, message template, or segment.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.resource.tag(ctx, resource_arn=value, tags_model=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.resource.tag resource_arn=value, tags_model=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagsModel": tags_model},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes one or more tags (keys and values) from an application, campaign, message template, or segment.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tag_keys(List): The key of the tag to remove from the resource. To remove multiple tags, append the tagKeys parameter and argument for each additional tag to remove, separated by an ampersand (&).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, rest_api_id: str, parent_id: str, path_part: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Resource resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        parent_id(str): [Required] The parent resource's identifier.
        path_part(str): The last path segment for this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.resource.create(
                ctx, rest_api_id=value, parent_id=value, path_part=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.resource.create rest_api_id=value, parent_id=value, path_part=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_resource",
        op_kwargs={
            "restApiId": rest_api_id,
            "parentId": parent_id,
            "pathPart": path_part,
        },
    )


async def delete(hub, ctx, rest_api_id: str, resource_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a Resource resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The identifier of the Resource resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.resource.delete(
                ctx, rest_api_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.resource.delete rest_api_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_resource",
        op_kwargs={"restApiId": rest_api_id, "resourceId": resource_id},
    )


async def get(hub, ctx, rest_api_id: str, resource_id: str, embed: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about a resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The identifier for the Resource resource.
        embed(List, optional): A query parameter to retrieve the specified resources embedded in the returned Resource representation in the response. This embed parameter value is a list of comma-separated strings. Currently, the request supports only retrieval of the embedded Method resources this way. The query parameter value must be a single-valued list and contain the "methods" string. For example, GET /restapis/{restapi_id}/resources/{resource_id}?embed=methods. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.resource.get(
                ctx, rest_api_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.resource.get rest_api_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_resource",
        op_kwargs={"restApiId": rest_api_id, "resourceId": resource_id, "embed": embed},
    )


async def get_all(
    hub,
    ctx,
    rest_api_id: str,
    position: str = None,
    limit: int = None,
    embed: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about a collection of Resource resources.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.
        embed(List, optional): A query parameter used to retrieve the specified resources embedded in the returned Resources resource in the response. This embed parameter value is a list of comma-separated strings. Currently, the request supports only retrieval of the embedded Method resources this way. The query parameter value must be a single-valued list and contain the "methods" string. For example, GET /restapis/{restapi_id}/resources?embed=methods. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.resource.get_all(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.resource.get_all rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_resources",
        op_kwargs={
            "restApiId": rest_api_id,
            "position": position,
            "limit": limit,
            "embed": embed,
        },
    )


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Adds or updates a tag on a given resource.

    Args:
        resource_arn(str): [Required] The ARN of a resource that can be tagged.
        tags(Dict): [Required] The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with aws:. The tag value can be up to 256 characters.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes a tag from a given resource.

    Args:
        resource_arn(str): [Required] The ARN of a resource that can be tagged.
        tag_keys(List): [Required] The Tag keys to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )


async def update(
    hub, ctx, rest_api_id: str, resource_id: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about a Resource resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The identifier of the Resource resource.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.resource.update(
                ctx, rest_api_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.resource.update rest_api_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_resource",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def add(
    hub, ctx, db_cluster_identifier: str, role_arn: str, feature_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Associates an Identity and Access Management (IAM) role from an Neptune DB cluster.

    Args:
        db_cluster_identifier(str): The name of the DB cluster to associate the IAM role with.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM role to associate with the Neptune DB cluster, for example arn:aws:iam::123456789012:role/NeptuneAccessRole.
        feature_name(str, optional): The name of the feature for the Neptune DB cluster that the IAM role is to be associated with. For the list of supported feature names, see DBEngineVersion. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.role.to_db_cluster.add(
                ctx, db_cluster_identifier=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.role.to_db_cluster.add db_cluster_identifier=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="add_role_to_db_cluster",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "RoleArn": role_arn,
            "FeatureName": feature_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, iam_instance_profile: Dict, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates an IAM instance profile with a running or stopped instance. You cannot associate more than one IAM instance profile with an instance.

    Args:
        iam_instance_profile(Dict): The IAM instance profile.
        instance_id(str): The ID of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.iam_instance_profile.init.associate(
                ctx, iam_instance_profile=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.iam_instance_profile.init.associate iam_instance_profile=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="associate_iam_instance_profile",
        op_kwargs={
            "IamInstanceProfile": iam_instance_profile,
            "InstanceId": instance_id,
        },
    )


async def disassociate(hub, ctx, association_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates an IAM instance profile from a running or stopped instance. Use DescribeIamInstanceProfileAssociations to get the association ID.

    Args:
        association_id(str): The ID of the IAM instance profile association.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.iam_instance_profile.init.disassociate(
                ctx, association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.iam_instance_profile.init.disassociate association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disassociate_iam_instance_profile",
        op_kwargs={"AssociationId": association_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def delete(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Deletes all servers from your server catalog.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.server.catalog.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.server.catalog.delete
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="sms", operation="delete_server_catalog", op_kwargs={}
    )


async def import_(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Gathers a complete list of on-premises servers. Connectors must be installed and monitoring all servers to import. This call returns immediately, but might take additional time to retrieve all the servers.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.server.catalog.import(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.server.catalog.import
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="sms", operation="import_server_catalog", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(hub, ctx, role_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the permissions boundary for the specified IAM role.   Deleting the permissions boundary for a role might increase its permissions. For example, it might allow anyone who assumes the role to perform all the actions granted in its permissions policies.

    Args:
        role_name(str): The name (friendly name, not ARN) of the IAM role from which you want to remove the permissions boundary.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.permission_boundary.delete(ctx, role_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.permission_boundary.delete role_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_role_permissions_boundary",
        op_kwargs={"RoleName": role_name},
    )


async def put(hub, ctx, role_name: str, permissions_boundary: str) -> None:
    r"""
    **Autogenerated function**

    Adds or updates the policy that is specified as the IAM role's permissions boundary. You can use an Amazon Web Services managed policy or a customer managed policy to set the boundary for a role. Use the boundary to control the maximum permissions that the role can have. Setting a permissions boundary is an advanced feature that can affect the permissions for the role. You cannot set the boundary for a service-linked role.   Policies used as permissions boundaries do not provide permissions. You must also attach a permissions policy to the role. To learn how the effective permissions for a role are evaluated, see IAM JSON policy evaluation logic in the IAM User Guide.

    Args:
        role_name(str): The name (friendly name, not ARN) of the IAM role for which you want to set the permissions boundary.
        permissions_boundary(str): The ARN of the policy that is used to set the permissions boundary for the role.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.permission_boundary.put(
                ctx, role_name=value, permissions_boundary=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.permission_boundary.put role_name=value, permissions_boundary=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="put_role_permissions_boundary",
        op_kwargs={"RoleName": role_name, "PermissionsBoundary": permissions_boundary},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, key_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the deletion of a customer master key (CMK). When this operation succeeds, the key state of the CMK is Disabled. To enable the CMK, use EnableKey.  For more information about scheduling and canceling deletion of a CMK, see Deleting Customer Master Keys in the AWS Key Management Service Developer Guide. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:CancelKeyDeletion (key policy)  Related operations: ScheduleKeyDeletion

    Args:
        key_id(str): Identifies the customer master key (CMK) whose deletion is being canceled. Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.deletion.cancel(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.deletion.cancel key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="cancel_key_deletion",
        op_kwargs={"KeyId": key_id},
    )


async def schedule(hub, ctx, key_id: str, pending_window_in_days: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Schedules the deletion of a customer master key (CMK). By default, AWS KMS applies a waiting period of 30 days, but you can specify a waiting period of 7-30 days. When this operation is successful, the key state of the CMK changes to PendingDeletion and the key can't be used in any cryptographic operations. It remains in this state for the duration of the waiting period. Before the waiting period ends, you can use CancelKeyDeletion to cancel the deletion of the CMK. After the waiting period ends, AWS KMS deletes the CMK, its key material, and all AWS KMS data associated with it, including all aliases that refer to it.  Deleting a CMK is a destructive and potentially dangerous operation. When a CMK is deleted, all data that was encrypted under the CMK is unrecoverable. (The only exception is a multi-Region replica key.) To prevent the use of a CMK without deleting it, use DisableKey.   If you schedule deletion of a CMK from a custom key store, when the waiting period expires, ScheduleKeyDeletion deletes the CMK from AWS KMS. Then AWS KMS makes a best effort to delete the key material from the associated AWS CloudHSM cluster. However, you might need to manually delete the orphaned key material from the cluster and its backups. You can schedule the deletion of a multi-Region primary key and its replica keys at any time. However, AWS KMS will not delete a multi-Region primary key with existing replica keys. If you schedule the deletion of a primary key with replicas, its key state changes to PendingReplicaDeletion and it cannot be replicated or used in cryptographic operations. This status can continue indefinitely. When the last of its replicas keys is deleted (not just scheduled), the key state of the primary key changes to PendingDeletion and its waiting period (PendingWindowInDays) begins. For details, see Deleting multi-Region keys in the AWS Key Management Service Developer Guide.  For more information about scheduling a CMK for deletion, see Deleting Customer Master Keys in the AWS Key Management Service Developer Guide. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:ScheduleKeyDeletion (key policy)  Related operations     CancelKeyDeletion     DisableKey

    Args:
        key_id(str): The unique identifier of the customer master key (CMK) to delete. Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        pending_window_in_days(int, optional): The waiting period, specified in number of days. After the waiting period ends, AWS KMS deletes the customer master key (CMK). If the CMK is a multi-Region primary key with replicas, the waiting period begins when the last of its replica keys is deleted. Otherwise, the waiting period begins immediately. This value is optional. If you include a value, it must be between 7 and 30, inclusive. If you do not include a value, it defaults to 30. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.deletion.schedule(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.deletion.schedule key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="schedule_key_deletion",
        op_kwargs={"KeyId": key_id, "PendingWindowInDays": pending_window_in_days},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    thing_group_name: str,
    parent_group_name: str = None,
    thing_group_properties: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a thing group.  This is a control plane operation. See Authorization for information about authorizing control plane actions.

    Args:
        thing_group_name(str): The thing group name to create.
        parent_group_name(str, optional): The name of the parent thing group. Defaults to None.
        thing_group_properties(Dict, optional): The thing group properties. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the thing group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.group.init.create(ctx, thing_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.group.init.create thing_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_thing_group",
        op_kwargs={
            "thingGroupName": thing_group_name,
            "parentGroupName": parent_group_name,
            "thingGroupProperties": thing_group_properties,
            "tags": tags,
        },
    )


async def delete(hub, ctx, thing_group_name: str, expected_version: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a thing group.

    Args:
        thing_group_name(str): The name of the thing group to delete.
        expected_version(int, optional): The expected version of the thing group to delete. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.group.init.delete(ctx, thing_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.group.init.delete thing_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_thing_group",
        op_kwargs={
            "thingGroupName": thing_group_name,
            "expectedVersion": expected_version,
        },
    )


async def describe(hub, ctx, thing_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe a thing group.

    Args:
        thing_group_name(str): The name of the thing group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.group.init.describe(ctx, thing_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.group.init.describe thing_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_thing_group",
        op_kwargs={"thingGroupName": thing_group_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    parent_group: str = None,
    name_prefix_filter: str = None,
    recursive: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the thing groups in your account.

    Args:
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.
        parent_group(str, optional): A filter that limits the results to those with the specified parent group. Defaults to None.
        name_prefix_filter(str, optional): A filter that limits the results to those with the specified name prefix. Defaults to None.
        recursive(bool, optional): If true, return child groups as well. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.group.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.group.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_thing_groups",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "parentGroup": parent_group,
            "namePrefixFilter": name_prefix_filter,
            "recursive": recursive,
        },
    )


async def update(
    hub,
    ctx,
    thing_group_name: str,
    thing_group_properties: Dict,
    expected_version: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update a thing group.

    Args:
        thing_group_name(str): The thing group to update.
        thing_group_properties(Dict): The thing group properties.
        expected_version(int, optional): The expected version of the thing group. If this does not match the version of the thing group being updated, the update will fail. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.group.init.update(
                ctx, thing_group_name=value, thing_group_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.group.init.update thing_group_name=value, thing_group_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_thing_group",
        op_kwargs={
            "thingGroupName": thing_group_name,
            "thingGroupProperties": thing_group_properties,
            "expectedVersion": expected_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, database_name: str, function_input: Dict, catalog_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new function definition in the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which to create the function. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database in which to create the function.
        function_input(Dict): A FunctionInput object that defines the function to create in the Data Catalog.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.user_defined_function.create(
                ctx, database_name=value, function_input=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.user_defined_function.create database_name=value, function_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_user_defined_function",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "FunctionInput": function_input,
        },
    )


async def delete(
    hub, ctx, database_name: str, function_name: str, catalog_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing function definition from the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the function to be deleted is located. If none is supplied, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database where the function is located.
        function_name(str): The name of the function definition to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.user_defined_function.delete(
                ctx, database_name=value, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.user_defined_function.delete database_name=value, function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_user_defined_function",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "FunctionName": function_name,
        },
    )


async def get(
    hub, ctx, database_name: str, function_name: str, catalog_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a specified function definition from the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the function to be retrieved is located. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database where the function is located.
        function_name(str): The name of the function.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.user_defined_function.get(
                ctx, database_name=value, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.user_defined_function.get database_name=value, function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_user_defined_function",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "FunctionName": function_name,
        },
    )


async def get_all(
    hub,
    ctx,
    pattern: str,
    catalog_id: str = None,
    database_name: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves multiple function definitions from the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the functions to be retrieved are located. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str, optional): The name of the catalog database where the functions are located. If none is provided, functions from all the databases across the catalog will be returned. Defaults to None.
        pattern(str): An optional function-name pattern string that filters the function definitions returned.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.
        max_results(int, optional): The maximum number of functions to return in one response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.user_defined_function.get_all(ctx, pattern=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.user_defined_function.get_all pattern=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_user_defined_functions",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "Pattern": pattern,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    database_name: str,
    function_name: str,
    function_input: Dict,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing function definition in the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the function to be updated is located. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database where the function to be updated is located.
        function_name(str): The name of the function.
        function_input(Dict): A FunctionInput object that redefines the function in the Data Catalog.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.user_defined_function.update(
                ctx, database_name=value, function_name=value, function_input=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.user_defined_function.update database_name=value, function_name=value, function_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_user_defined_function",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "FunctionName": function_name,
            "FunctionInput": function_input,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, check_id: str, language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the results of the AWS Trusted Advisor check that has the specified check ID. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation. The response contains a TrustedAdvisorCheckResult object, which contains these three objects:    TrustedAdvisorCategorySpecificSummary     TrustedAdvisorResourceDetail     TrustedAdvisorResourcesSummary    In addition, the response contains these fields:    status - The alert status of the check can be ok (green), warning (yellow), error (red), or not_available.    timestamp - The time of the last refresh of the check.    checkId - The unique identifier for the check.      You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        check_id(str): The unique identifier for the Trusted Advisor check.
        language(str, optional): The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.trusted_advisor_check.result.describe(
                ctx, check_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.trusted_advisor_check.result.describe check_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="describe_trusted_advisor_check_result",
        op_kwargs={"checkId": check_id, "language": language},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    input_bucket: str,
    role: str,
    output_bucket: str = None,
    aws_kms_key_arn: str = None,
    notifications: Dict = None,
    content_config: Dict = None,
    thumbnail_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    The CreatePipeline operation creates a pipeline with settings that you specify.

    Args:
        name(str): The name of the pipeline. We recommend that the name be unique within the AWS account, but uniqueness is not enforced. Constraints: Maximum 40 characters.
        input_bucket(str): The Amazon S3 bucket in which you saved the media files that you want to transcode.
        output_bucket(str, optional): The Amazon S3 bucket in which you want Elastic Transcoder to save the transcoded files. (Use this, or use ContentConfig:Bucket plus ThumbnailConfig:Bucket.) Specify this value when all of the following are true:   You want to save transcoded files, thumbnails (if any), and playlists (if any) together in one bucket.   You do not want to specify the users or groups who have access to the transcoded files, thumbnails, and playlists.   You do not want to specify the permissions that Elastic Transcoder grants to the files.   When Elastic Transcoder saves files in OutputBucket, it grants full control over the files only to the AWS account that owns the role that is specified by Role.    You want to associate the transcoded files and thumbnails with the Amazon S3 Standard storage class.   If you want to save transcoded files and playlists in one bucket and thumbnails in another bucket, specify which users can access the transcoded files or the permissions the users have, or change the Amazon S3 storage class, omit OutputBucket and specify values for ContentConfig and ThumbnailConfig instead. Defaults to None.
        role(str): The IAM Amazon Resource Name (ARN) for the role that you want Elastic Transcoder to use to create the pipeline.
        aws_kms_key_arn(str, optional): The AWS Key Management Service (AWS KMS) key that you want to use with this pipeline. If you use either s3 or s3-aws-kms as your Encryption:Mode, you don't need to provide a key with your job because a default key, known as an AWS-KMS key, is created for you automatically. You need to provide an AWS-KMS key only if you want to use a non-default AWS-KMS key, or if you are using an Encryption:Mode of aes-cbc-pkcs7, aes-ctr, or aes-gcm. Defaults to None.
        notifications(Dict, optional): The Amazon Simple Notification Service (Amazon SNS) topic that you want to notify to report job status.  To receive notifications, you must also subscribe to the new topic in the Amazon SNS console.     Progressing: The topic ARN for the Amazon Simple Notification Service (Amazon SNS) topic that you want to notify when Elastic Transcoder has started to process a job in this pipeline. This is the ARN that Amazon SNS returned when you created the topic. For more information, see Create a Topic in the Amazon Simple Notification Service Developer Guide.    Complete: The topic ARN for the Amazon SNS topic that you want to notify when Elastic Transcoder has finished processing a job in this pipeline. This is the ARN that Amazon SNS returned when you created the topic.    Warning: The topic ARN for the Amazon SNS topic that you want to notify when Elastic Transcoder encounters a warning condition while processing a job in this pipeline. This is the ARN that Amazon SNS returned when you created the topic.    Error: The topic ARN for the Amazon SNS topic that you want to notify when Elastic Transcoder encounters an error condition while processing a job in this pipeline. This is the ARN that Amazon SNS returned when you created the topic.  . Defaults to None.
        content_config(Dict, optional): The optional ContentConfig object specifies information about the Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists: which bucket to use, which users you want to have access to the files, the type of access you want users to have, and the storage class that you want to assign to the files. If you specify values for ContentConfig, you must also specify values for ThumbnailConfig. If you specify values for ContentConfig and ThumbnailConfig, omit the OutputBucket object.    Bucket: The Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists.    Permissions (Optional): The Permissions object specifies which users you want to have access to transcoded files and the type of access you want them to have. You can grant permissions to a maximum of 30 users and/or predefined Amazon S3 groups.    Grantee Type: Specify the type of value that appears in the Grantee object:     Canonical: The value in the Grantee object is either the canonical user ID for an AWS account or an origin access identity for an Amazon CloudFront distribution. For more information about canonical user IDs, see Access Control List (ACL) Overview in the Amazon Simple Storage Service Developer Guide. For more information about using CloudFront origin access identities to require that users use CloudFront URLs instead of Amazon S3 URLs, see Using an Origin Access Identity to Restrict Access to Your Amazon S3 Content.  A canonical user ID is not the same as an AWS account number.     Email: The value in the Grantee object is the registered email address of an AWS account.    Group: The value in the Grantee object is one of the following predefined Amazon S3 groups: AllUsers, AuthenticatedUsers, or LogDelivery.      Grantee: The AWS user or group that you want to have access to transcoded files and playlists. To identify the user or group, you can specify the canonical user ID for an AWS account, an origin access identity for a CloudFront distribution, the registered email address of an AWS account, or a predefined Amazon S3 group     Access: The permission that you want to give to the AWS user that you specified in Grantee. Permissions are granted on the files that Elastic Transcoder adds to the bucket, including playlists and video files. Valid values include:     READ: The grantee can read the objects and metadata for objects that Elastic Transcoder adds to the Amazon S3 bucket.    READ_ACP: The grantee can read the object ACL for objects that Elastic Transcoder adds to the Amazon S3 bucket.    WRITE_ACP: The grantee can write the ACL for the objects that Elastic Transcoder adds to the Amazon S3 bucket.    FULL_CONTROL: The grantee has READ, READ_ACP, and WRITE_ACP permissions for the objects that Elastic Transcoder adds to the Amazon S3 bucket.      StorageClass: The Amazon S3 storage class, Standard or ReducedRedundancy, that you want Elastic Transcoder to assign to the video files and playlists that it stores in your Amazon S3 bucket.  . Defaults to None.
        thumbnail_config(Dict, optional): The ThumbnailConfig object specifies several values, including the Amazon S3 bucket in which you want Elastic Transcoder to save thumbnail files, which users you want to have access to the files, the type of access you want users to have, and the storage class that you want to assign to the files. If you specify values for ContentConfig, you must also specify values for ThumbnailConfig even if you don't want to create thumbnails. If you specify values for ContentConfig and ThumbnailConfig, omit the OutputBucket object.    Bucket: The Amazon S3 bucket in which you want Elastic Transcoder to save thumbnail files.    Permissions (Optional): The Permissions object specifies which users and/or predefined Amazon S3 groups you want to have access to thumbnail files, and the type of access you want them to have. You can grant permissions to a maximum of 30 users and/or predefined Amazon S3 groups.    GranteeType: Specify the type of value that appears in the Grantee object:     Canonical: The value in the Grantee object is either the canonical user ID for an AWS account or an origin access identity for an Amazon CloudFront distribution.  A canonical user ID is not the same as an AWS account number.     Email: The value in the Grantee object is the registered email address of an AWS account.     Group: The value in the Grantee object is one of the following predefined Amazon S3 groups: AllUsers, AuthenticatedUsers, or LogDelivery.      Grantee: The AWS user or group that you want to have access to thumbnail files. To identify the user or group, you can specify the canonical user ID for an AWS account, an origin access identity for a CloudFront distribution, the registered email address of an AWS account, or a predefined Amazon S3 group.     Access: The permission that you want to give to the AWS user that you specified in Grantee. Permissions are granted on the thumbnail files that Elastic Transcoder adds to the bucket. Valid values include:     READ: The grantee can read the thumbnails and metadata for objects that Elastic Transcoder adds to the Amazon S3 bucket.    READ_ACP: The grantee can read the object ACL for thumbnails that Elastic Transcoder adds to the Amazon S3 bucket.    WRITE_ACP: The grantee can write the ACL for the thumbnails that Elastic Transcoder adds to the Amazon S3 bucket.    FULL_CONTROL: The grantee has READ, READ_ACP, and WRITE_ACP permissions for the thumbnails that Elastic Transcoder adds to the Amazon S3 bucket.      StorageClass: The Amazon S3 storage class, Standard or ReducedRedundancy, that you want Elastic Transcoder to assign to the thumbnails that it stores in your Amazon S3 bucket.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.pipeline.init.create(
                ctx, name=value, input_bucket=value, role=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.pipeline.init.create name=value, input_bucket=value, role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="create_pipeline",
        op_kwargs={
            "Name": name,
            "InputBucket": input_bucket,
            "OutputBucket": output_bucket,
            "Role": role,
            "AwsKmsKeyArn": aws_kms_key_arn,
            "Notifications": notifications,
            "ContentConfig": content_config,
            "ThumbnailConfig": thumbnail_config,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    The DeletePipeline operation removes a pipeline.  You can only delete a pipeline that has never been used or that is not currently in use (doesn't contain any active jobs). If the pipeline is currently in use, DeletePipeline returns an error.

    Args:
        id_(str): The identifier of the pipeline that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.pipeline.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.pipeline.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="delete_pipeline",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, ascending: str = None, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    The ListPipelines operation gets a list of the pipelines associated with the current AWS account.

    Args:
        ascending(str, optional): To list pipelines in chronological order by the date and time that they were created, enter true. To list pipelines in reverse chronological order, enter false. Defaults to None.
        page_token(str, optional): When Elastic Transcoder returns more than one page of results, use pageToken in subsequent GET requests to get each successive page of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.pipeline.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.pipeline.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="list_pipelines",
        op_kwargs={"Ascending": ascending, "PageToken": page_token},
    )


async def read(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    The ReadPipeline operation gets detailed information about a pipeline.

    Args:
        id_(str): The identifier of the pipeline to read.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.pipeline.init.read(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.pipeline.init.read id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="read_pipeline",
        op_kwargs={"Id": id_},
    )


async def update(
    hub,
    ctx,
    id_: str,
    name: str = None,
    input_bucket: str = None,
    role: str = None,
    aws_kms_key_arn: str = None,
    notifications: Dict = None,
    content_config: Dict = None,
    thumbnail_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Use the UpdatePipeline operation to update settings for a pipeline.  When you change pipeline settings, your changes take effect immediately. Jobs that you have already submitted and that Elastic Transcoder has not started to process are affected in addition to jobs that you submit after you change settings.

    Args:
        id_(str): The ID of the pipeline that you want to update.
        name(str, optional): The name of the pipeline. We recommend that the name be unique within the AWS account, but uniqueness is not enforced. Constraints: Maximum 40 characters. Defaults to None.
        input_bucket(str, optional): The Amazon S3 bucket in which you saved the media files that you want to transcode and the graphics that you want to use as watermarks. Defaults to None.
        role(str, optional): The IAM Amazon Resource Name (ARN) for the role that you want Elastic Transcoder to use to transcode jobs for this pipeline. Defaults to None.
        aws_kms_key_arn(str, optional): The AWS Key Management Service (AWS KMS) key that you want to use with this pipeline. If you use either s3 or s3-aws-kms as your Encryption:Mode, you don't need to provide a key with your job because a default key, known as an AWS-KMS key, is created for you automatically. You need to provide an AWS-KMS key only if you want to use a non-default AWS-KMS key, or if you are using an Encryption:Mode of aes-cbc-pkcs7, aes-ctr, or aes-gcm. Defaults to None.
        notifications(Dict, optional): The topic ARN for the Amazon Simple Notification Service (Amazon SNS) topic that you want to notify to report job status.  To receive notifications, you must also subscribe to the new topic in the Amazon SNS console.     Progressing: The topic ARN for the Amazon Simple Notification Service (Amazon SNS) topic that you want to notify when Elastic Transcoder has started to process jobs that are added to this pipeline. This is the ARN that Amazon SNS returned when you created the topic.    Complete: The topic ARN for the Amazon SNS topic that you want to notify when Elastic Transcoder has finished processing a job. This is the ARN that Amazon SNS returned when you created the topic.    Warning: The topic ARN for the Amazon SNS topic that you want to notify when Elastic Transcoder encounters a warning condition. This is the ARN that Amazon SNS returned when you created the topic.    Error: The topic ARN for the Amazon SNS topic that you want to notify when Elastic Transcoder encounters an error condition. This is the ARN that Amazon SNS returned when you created the topic.  . Defaults to None.
        content_config(Dict, optional): The optional ContentConfig object specifies information about the Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists: which bucket to use, which users you want to have access to the files, the type of access you want users to have, and the storage class that you want to assign to the files. If you specify values for ContentConfig, you must also specify values for ThumbnailConfig. If you specify values for ContentConfig and ThumbnailConfig, omit the OutputBucket object.    Bucket: The Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists.    Permissions (Optional): The Permissions object specifies which users you want to have access to transcoded files and the type of access you want them to have. You can grant permissions to a maximum of 30 users and/or predefined Amazon S3 groups.    Grantee Type: Specify the type of value that appears in the Grantee object:    Canonical: The value in the Grantee object is either the canonical user ID for an AWS account or an origin access identity for an Amazon CloudFront distribution. For more information about canonical user IDs, see Access Control List (ACL) Overview in the Amazon Simple Storage Service Developer Guide. For more information about using CloudFront origin access identities to require that users use CloudFront URLs instead of Amazon S3 URLs, see Using an Origin Access Identity to Restrict Access to Your Amazon S3 Content.  A canonical user ID is not the same as an AWS account number.     Email: The value in the Grantee object is the registered email address of an AWS account.    Group: The value in the Grantee object is one of the following predefined Amazon S3 groups: AllUsers, AuthenticatedUsers, or LogDelivery.      Grantee: The AWS user or group that you want to have access to transcoded files and playlists. To identify the user or group, you can specify the canonical user ID for an AWS account, an origin access identity for a CloudFront distribution, the registered email address of an AWS account, or a predefined Amazon S3 group     Access: The permission that you want to give to the AWS user that you specified in Grantee. Permissions are granted on the files that Elastic Transcoder adds to the bucket, including playlists and video files. Valid values include:     READ: The grantee can read the objects and metadata for objects that Elastic Transcoder adds to the Amazon S3 bucket.    READ_ACP: The grantee can read the object ACL for objects that Elastic Transcoder adds to the Amazon S3 bucket.     WRITE_ACP: The grantee can write the ACL for the objects that Elastic Transcoder adds to the Amazon S3 bucket.    FULL_CONTROL: The grantee has READ, READ_ACP, and WRITE_ACP permissions for the objects that Elastic Transcoder adds to the Amazon S3 bucket.      StorageClass: The Amazon S3 storage class, Standard or ReducedRedundancy, that you want Elastic Transcoder to assign to the video files and playlists that it stores in your Amazon S3 bucket.  . Defaults to None.
        thumbnail_config(Dict, optional): The ThumbnailConfig object specifies several values, including the Amazon S3 bucket in which you want Elastic Transcoder to save thumbnail files, which users you want to have access to the files, the type of access you want users to have, and the storage class that you want to assign to the files. If you specify values for ContentConfig, you must also specify values for ThumbnailConfig even if you don't want to create thumbnails. If you specify values for ContentConfig and ThumbnailConfig, omit the OutputBucket object.    Bucket: The Amazon S3 bucket in which you want Elastic Transcoder to save thumbnail files.    Permissions (Optional): The Permissions object specifies which users and/or predefined Amazon S3 groups you want to have access to thumbnail files, and the type of access you want them to have. You can grant permissions to a maximum of 30 users and/or predefined Amazon S3 groups.    GranteeType: Specify the type of value that appears in the Grantee object:    Canonical: The value in the Grantee object is either the canonical user ID for an AWS account or an origin access identity for an Amazon CloudFront distribution.  A canonical user ID is not the same as an AWS account number.     Email: The value in the Grantee object is the registered email address of an AWS account.    Group: The value in the Grantee object is one of the following predefined Amazon S3 groups: AllUsers, AuthenticatedUsers, or LogDelivery.      Grantee: The AWS user or group that you want to have access to thumbnail files. To identify the user or group, you can specify the canonical user ID for an AWS account, an origin access identity for a CloudFront distribution, the registered email address of an AWS account, or a predefined Amazon S3 group.     Access: The permission that you want to give to the AWS user that you specified in Grantee. Permissions are granted on the thumbnail files that Elastic Transcoder adds to the bucket. Valid values include:     READ: The grantee can read the thumbnails and metadata for objects that Elastic Transcoder adds to the Amazon S3 bucket.    READ_ACP: The grantee can read the object ACL for thumbnails that Elastic Transcoder adds to the Amazon S3 bucket.    WRITE_ACP: The grantee can write the ACL for the thumbnails that Elastic Transcoder adds to the Amazon S3 bucket.    FULL_CONTROL: The grantee has READ, READ_ACP, and WRITE_ACP permissions for the thumbnails that Elastic Transcoder adds to the Amazon S3 bucket.       StorageClass: The Amazon S3 storage class, Standard or ReducedRedundancy, that you want Elastic Transcoder to assign to the thumbnails that it stores in your Amazon S3 bucket.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.pipeline.init.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.pipeline.init.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="update_pipeline",
        op_kwargs={
            "Id": id_,
            "Name": name,
            "InputBucket": input_bucket,
            "Role": role,
            "AwsKmsKeyArn": aws_kms_key_arn,
            "Notifications": notifications,
            "ContentConfig": content_config,
            "ThumbnailConfig": thumbnail_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, report_group_arn: str, trend_field: str, num_of_reports: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Analyzes and accumulates test report values for the specified test reports.

    Args:
        report_group_arn(str): The ARN of the report group that contains the reports to analyze.
        num_of_reports(int, optional): The number of reports to analyze. This operation always retrieves the most recent reports. If this parameter is omitted, the most recent 100 reports are analyzed. Defaults to None.
        trend_field(str): The test report value to accumulate. This must be one of the following values:  Test reports:   DURATION  Accumulate the test run times for the specified reports.  PASS_RATE  Accumulate the percentage of tests that passed for the specified test reports.  TOTAL  Accumulate the total number of tests for the specified test reports.      Code coverage reports:   BRANCH_COVERAGE  Accumulate the branch coverage percentages for the specified test reports.  BRANCHES_COVERED  Accumulate the branches covered values for the specified test reports.  BRANCHES_MISSED  Accumulate the branches missed values for the specified test reports.  LINE_COVERAGE  Accumulate the line coverage percentages for the specified test reports.  LINES_COVERED  Accumulate the lines covered values for the specified test reports.  LINES_MISSED  Accumulate the lines not covered values for the specified test reports.    .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.report.group.trend.get(
                ctx, report_group_arn=value, trend_field=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.report.group.trend.get report_group_arn=value, trend_field=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="get_report_group_trend",
        op_kwargs={
            "reportGroupArn": report_group_arn,
            "numOfReports": num_of_reports,
            "trendField": trend_field,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, auto_scaling_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels an instance refresh operation in progress. Cancellation does not roll back any replacements that have already been completed, but it prevents new replacements from being started.  This operation is part of the instance refresh feature in Amazon EC2 Auto Scaling, which helps you update instances in your Auto Scaling group after you make configuration changes.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.instance.refresh.cancel(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.instance.refresh.cancel auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="cancel_instance_refresh",
        op_kwargs={"AutoScalingGroupName": auto_scaling_group_name},
    )


async def describe_all(
    hub,
    ctx,
    auto_scaling_group_name: str,
    instance_refresh_ids: List = None,
    next_token: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the instance refreshes for the specified Auto Scaling group. This operation is part of the instance refresh feature in Amazon EC2 Auto Scaling, which helps you update instances in your Auto Scaling group after you make configuration changes. To help you determine the status of an instance refresh, this operation returns information about the instance refreshes you previously initiated, including their status, end time, the percentage of the instance refresh that is complete, and the number of instances remaining to update before the instance refresh is complete. The following are the possible statuses:     Pending - The request was created, but the operation has not started.    InProgress - The operation is in progress.    Successful - The operation completed successfully.    Failed - The operation failed to complete. You can troubleshoot using the status reason and the scaling activities.     Cancelling - An ongoing operation is being cancelled. Cancellation does not roll back any replacements that have already been completed, but it prevents new replacements from being started.     Cancelled - The operation is cancelled.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        instance_refresh_ids(List, optional): One or more instance refresh IDs. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 50 and the maximum value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.instance.refresh.describe_all(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.instance.refresh.describe_all auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_instance_refreshes",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "InstanceRefreshIds": instance_refresh_ids,
            "NextToken": next_token,
            "MaxRecords": max_records,
        },
    )


async def start(
    hub,
    ctx,
    auto_scaling_group_name: str,
    strategy: str = None,
    preferences: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a new instance refresh operation, which triggers a rolling replacement of previously launched instances in the Auto Scaling group with a new group of instances. This operation is part of the instance refresh feature in Amazon EC2 Auto Scaling, which helps you update instances in your Auto Scaling group after you make configuration changes. If the call succeeds, it creates a new instance refresh request with a unique ID that you can use to track its progress. To query its status, call the DescribeInstanceRefreshes API. To describe the instance refreshes that have already run, call the DescribeInstanceRefreshes API. To cancel an instance refresh operation in progress, use the CancelInstanceRefresh API.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        strategy(str, optional): The strategy to use for the instance refresh. The only valid value is Rolling. A rolling update is an update that is applied to all instances in an Auto Scaling group until all instances have been updated. A rolling update can fail due to failed health checks or if instances are on standby or are protected from scale in. If the rolling update process fails, any instances that were already replaced are not rolled back to their previous configuration. . Defaults to None.
        preferences(Dict, optional): Set of preferences associated with the instance refresh request. If not provided, the default values are used. For MinHealthyPercentage, the default value is 90. For InstanceWarmup, the default is to use the value specified for the health check grace period for the Auto Scaling group. For more information, see RefreshPreferences in the Amazon EC2 Auto Scaling API Reference. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.instance.refresh.start(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.instance.refresh.start auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="start_instance_refresh",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "Strategy": strategy,
            "Preferences": preferences,
        },
    )
